@@ -20,10 +20,12 @@ $lang['categories'] = 'Catégories';
 $lang['edit'] = 'Editer';
 $lang['delete'] = 'Supprimer';
 $lang['areyousure'] = 'Êtes-vous sûr ? Cette opération est irréversible';
+$lang['copy'] = 'Copier';
 
 # Events
 $lang['addevent'] = 'Ajouter un événement';
 $lang['editevent'] = 'Modifier un événement';
+$lang['copyevent'] = 'Copier un événement';
 $lang['eventdescription'] = 'Description';
 $lang['start_datetime'] = 'Date et heure de début';
 $lang['end_datetime'] = 'Date et heure de fin';
@@ -149,6 +151,17 @@ $lang['param_summarytemplate'] = "Utilisé uniquement avec l'action <em>default<
 $lang['param_detailtemplate'] = "Utilisé uniquement avec les actions <em>default</em> et <em>detail</em>, vous permet de préciser le gabarit à utiliser pour l'affichage d'un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_registrationtemplate'] = "Utilisé uniquement avec l'action <em>register</em>, vous permet de préciser le gabarit à utiliser pour l'affichage du formulaire d'inscription à un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_myevents'] = "true/false - Utilisé uniquement avec l'action <em>default</em>, affiche uniquement les évènements auxquels l'utilisateur FEU actuellement connecté est enregistré. Si personne n'est connecté, le paramètre est ignoré - Astuce : utilisez cette option sur une page de type 'Contenu protégé'";
+$lang['param_sortby'] = "Utilisé uniquement avec l'action <em>default</em>, cette option vous permet de définir un critère de tri des évènements. Valeurs possibles :
+<ul>
+	<li>name : <em>default</em> - Tri par nom d'évènement</li>
+	<li>description : tri selon la description</li>
+	<li>start_datetime : tri selon la date/heure de début</li>
+	<li>end_datetime : tri selon la date/heure de fin</li>
+	<li>capacity : tri selon la capacité (note : illimitée vaut 0)</li>
+	<li>price : tri selon le prix</li>
+	<li>capacity_per_feu : tri selon le nombre d'inscriptions autorisées par utilisateur (note : illimitée vaut 0)</li>
+</ul>";
+$lang['param_sortorder'] = "ASC / DESC - Utilisé uniquement avec l'action <em>default</em>, cette option vous permet de définir un ordre de tri ascendant ou descendant relatif au critère <em>sortby</em>";
 
 # Help
 $lang['help'] = "
@@ -176,6 +189,7 @@ Mathieu Muths, l'auteur de ce module : <a
 href=\"mailto:mailto:contact@airelibre.fr\">contact@airelibre.fr</a></li>
 <li>Les Forums CMS Made Simple sont aussi une préciseuse source
 d'informations.</li>
+<li>Suivez l'auteur sur Twitter : <a href='http://www.twitter.com/aire_libre' target='_blank'>http://www.twitter.com/aire_libre</a></li>
 <li>Si vous êtes francophone, n'hésitez pas à consulter le Forum CMS
 Made Simple Français où l'auteur du module est régulièrement présent
 (pseudo : <strong>airelibre</strong>)</li>
